# coding: utf-8
__author__ = 'jiyue'

from setuptools import setup, find_packages, Extension
from scikit_credit import version

with open('README.md') as f:
    readme_content = f.read()

packages = [
    'scikit_credit.encoder',
]

setup(
    name='scikit-credit',
    version=version,
    description='scikit-credit for qudian',
    long_description=readme_content,
    author='Yue Ji',
    author_email='jiyue@quandian.com',
    url='https://git.qufenqi.com/risk-data-scientist/scikit-credit',
    keywords='scikit credit',
    license='MIT',
    packages=find_packages(exclude=['test']),
    package_dir={'scikit-credit': 'src'},
    install_requires=['scikit-learn', 'pandas', 'numpy', 'scipy']
)



import encoder
from sklearn.model_selection import cross_val_score
from sklearn.metrics import roc_curve, auc,roc_auc_score,accuracy_score

__author__ = 'jiyue'

import pandas as pd

df = pd.read_csv(
    '/home/jiyue/git/myproject/deeplearning/scikit-credit/scikit-credit/scikit_credit/data/tmp_risk_modeling_slice.csv',
    sep='\t')

x = df.loc[:, ['max_overdue_days', 'orign_amount', 'order_num']]
y = df['label']
woeEncoder = encoder.WoeEncoder()
woeEncoder.fit_transform(x.values, y.values)


y_pred_score = df['sdsy_score']
y_test = df['label']

fpr, tpr, thresholds = roc_curve(y_true=y_test.values,y_score= y_pred_score.values)
